API docs for “spamfighter.core.counters.IAtomCounter”

# Class s.c.c.IAtomCounter(Interface):

Part of spamfighter.core.counters View Source View In Hierarchy

Одиночный счетчик (одно значение). Счетчик рассчитывает своё значение для определенного периода времени.

Method | period | Период времени, за который собирается значение счетчика.
Method | value | Текущее значение счетчика для данного периода.
Method | increment | Увеличить значение счетчика на указанное значение.
Method | label | Подпись счетчика, описывающая период его работы.
Method | count | Число увеличений счетчика.

def period(): (source)
Период времени, за который собирается значение счетчика.

Returns | период времени, секунды (type: `int` )

def value(): (source)
Текущее значение счетчика для данного периода.

def increment(value=1): (source)
Увеличить значение счетчика на указанное значение.

Parameters | value | значение инкремента

def label(): (source)
Подпись счетчика, описывающая период его работы.

Returns | (type: `str` )

def count(): (source)
Число увеличений счетчика.

Returns | (type: `int` )